@@ -134,9 +134,8 @@ pub type WrappedDecoratorFunc = dyn Fn(
     Option<&mut dyn Any>
 ) -> Result<()>;
 
-macro_rules! wrapped_hook_setter{
-    ($field_name:ident, $field_type:ty, $func_name:ident, $dispatch_func:ident, $constructor:expr)
-        => {
+macro_rules! wrapped_hook_setter {
+    ($field_name:ident, $field_type:ty, $func_name:ident, $dispatch_func:ident, $constructor:expr) => {
         /// Sets the formatter hook to the provided value.
         ///
         /// This function accepts a wrapped version of the raw hook.
@@ -580,7 +579,7 @@ impl Formatter {
         instruction: &DecodedInstruction,
         buffer: &mut OutputBuffer,
         ip: Option<u64>,
-        user_data: Option<&mut dyn Any>,
+        mut user_data: Option<&mut dyn Any>,
     ) -> Result<()> {
         unsafe {
             check!(ZydisFormatterFormatInstructionEx(
@@ -589,10 +588,10 @@ impl Formatter {
                 buffer.buffer.as_mut_ptr() as *mut _,
                 buffer.buffer.len(),
                 ip_to_runtime_addr(ip),
-                match user_data {
-                    None => ptr::null_mut(),
-                    Some(mut x) => user_data_to_c_void(&mut x),
-                }
+                user_data
+                    .as_mut()
+                    .map(user_data_to_c_void)
+                    .unwrap_or_else(ptr::null_mut),
             ))
         }
     }
@@ -612,7 +611,7 @@ impl Formatter {
         operand_index: u8,
         buffer: &mut OutputBuffer,
         ip: Option<u64>,
-        user_data: Option<&mut dyn Any>,
+        mut user_data: Option<&mut dyn Any>,
     ) -> Result<()> {
         unsafe {
             check!(ZydisFormatterFormatOperandEx(
@@ -622,10 +621,10 @@ impl Formatter {
                 buffer.buffer.as_mut_ptr() as *mut _,
                 buffer.buffer.len(),
                 ip_to_runtime_addr(ip),
-                match user_data {
-                    None => ptr::null_mut(),
-                    Some(mut x) => user_data_to_c_void(&mut x),
-                }
+                user_data
+                    .as_mut()
+                    .map(user_data_to_c_void)
+                    .unwrap_or_else(ptr::null_mut),
             ))
         }
     }
@@ -637,7 +636,7 @@ impl Formatter {
         instruction: &DecodedInstruction,
         buffer: &'a mut [u8],
         ip: Option<u64>,
-        user_data: Option<&mut dyn Any>,
+        mut user_data: Option<&mut dyn Any>,
     ) -> Result<&'a FormatterToken<'a>> {
         unsafe {
             let mut token = MaybeUninit::uninit();
@@ -649,10 +648,10 @@ impl Formatter {
                     buffer.len(),
                     ip_to_runtime_addr(ip),
                     token.as_mut_ptr(),
-                    match user_data {
-                        None => ptr::null_mut(),
-                        Some(mut x) => user_data_to_c_void(&mut x),
-                    }
+                    user_data
+                        .as_mut()
+                        .map(user_data_to_c_void)
+                        .unwrap_or_else(ptr::null_mut),
                 ),
                 &*{ token.assume_init() }
             )
@@ -689,7 +688,7 @@ impl Formatter {
         index: u8,
         buffer: &'a mut [u8],
         ip: Option<u64>,
-        user_data: Option<&mut dyn Any>,
+        mut user_data: Option<&mut dyn Any>,
     ) -> Result<&'a FormatterToken<'a>> {
         unsafe {
             let mut token = MaybeUninit::uninit();
@@ -702,10 +701,10 @@ impl Formatter {
                     buffer.len(),
                     ip_to_runtime_addr(ip),
                     token.as_mut_ptr(),
-                    match user_data {
-                        None => ptr::null_mut(),
-                        Some(mut x) => user_data_to_c_void(&mut x),
-                    }
+                    user_data
+                        .as_mut()
+                        .map(user_data_to_c_void)
+                        .unwrap_or_else(ptr::null_mut)
                 ),
                 &*{ token.assume_init() }
             )
